==> openshift-model-monitoring-6.5.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ProbeSpecFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ProbeSpecFluent<A extends ProbeSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAuthorization instead.
   * @return The buildable object.
   */
  @Deprecated
  public SafeAuthorization getAuthorization();
  public SafeAuthorization buildAuthorization();
  public A withAuthorization(SafeAuthorization authorization);
  public Boolean hasAuthorization();
  public ProbeSpecFluent.AuthorizationNested<A> withNewAuthorization();
  public ProbeSpecFluent.AuthorizationNested<A> withNewAuthorizationLike(SafeAuthorization item);
  public ProbeSpecFluent.AuthorizationNested<A> editAuthorization();
  public ProbeSpecFluent.AuthorizationNested<A> editOrNewAuthorization();
  public ProbeSpecFluent.AuthorizationNested<A> editOrNewAuthorizationLike(SafeAuthorization item);
  
  /**
   * This method has been deprecated, please use method buildBasicAuth instead.
   * @return The buildable object.
   */
  @Deprecated
  public BasicAuth getBasicAuth();
  public BasicAuth buildBasicAuth();
  public A withBasicAuth(BasicAuth basicAuth);
  public Boolean hasBasicAuth();
  public ProbeSpecFluent.BasicAuthNested<A> withNewBasicAuth();
  public ProbeSpecFluent.BasicAuthNested<A> withNewBasicAuthLike(BasicAuth item);
  public ProbeSpecFluent.BasicAuthNested<A> editBasicAuth();
  public ProbeSpecFluent.BasicAuthNested<A> editOrNewBasicAuth();
  public ProbeSpecFluent.BasicAuthNested<A> editOrNewBasicAuthLike(BasicAuth item);
  public SecretKeySelector getBearerTokenSecret();
  public A withBearerTokenSecret(SecretKeySelector bearerTokenSecret);
  public Boolean hasBearerTokenSecret();
  public A withNewBearerTokenSecret(String key,String name,Boolean optional);
  public String getInterval();
  public A withInterval(String interval);
  public Boolean hasInterval();
  public String getJobName();
  public A withJobName(String jobName);
  public Boolean hasJobName();
  public Long getLabelLimit();
  public A withLabelLimit(Long labelLimit);
  public Boolean hasLabelLimit();
  public Long getLabelNameLengthLimit();
  public A withLabelNameLengthLimit(Long labelNameLengthLimit);
  public Boolean hasLabelNameLengthLimit();
  public Long getLabelValueLengthLimit();
  public A withLabelValueLengthLimit(Long labelValueLengthLimit);
  public Boolean hasLabelValueLengthLimit();
  public A addToMetricRelabelings(Integer index,RelabelConfig item);
  public A setToMetricRelabelings(Integer index,RelabelConfig item);
  public A addToMetricRelabelings(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig... items);
  public A addAllToMetricRelabelings(Collection<RelabelConfig> items);
  public A removeFromMetricRelabelings(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig... items);
  public A removeAllFromMetricRelabelings(Collection<RelabelConfig> items);
  public A removeMatchingFromMetricRelabelings(Predicate<RelabelConfigBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildMetricRelabelings instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RelabelConfig> getMetricRelabelings();
  public List<RelabelConfig> buildMetricRelabelings();
  public RelabelConfig buildMetricRelabeling(Integer index);
  public RelabelConfig buildFirstMetricRelabeling();
  public RelabelConfig buildLastMetricRelabeling();
  public RelabelConfig buildMatchingMetricRelabeling(Predicate<RelabelConfigBuilder> predicate);
  public Boolean hasMatchingMetricRelabeling(Predicate<RelabelConfigBuilder> predicate);
  public A withMetricRelabelings(List<RelabelConfig> metricRelabelings);
  public A withMetricRelabelings(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig... metricRelabelings);
  public Boolean hasMetricRelabelings();
  public ProbeSpecFluent.MetricRelabelingsNested<A> addNewMetricRelabeling();
  public ProbeSpecFluent.MetricRelabelingsNested<A> addNewMetricRelabelingLike(RelabelConfig item);
  public ProbeSpecFluent.MetricRelabelingsNested<A> setNewMetricRelabelingLike(Integer index,RelabelConfig item);
  public ProbeSpecFluent.MetricRelabelingsNested<A> editMetricRelabeling(Integer index);
  public ProbeSpecFluent.MetricRelabelingsNested<A> editFirstMetricRelabeling();
  public ProbeSpecFluent.MetricRelabelingsNested<A> editLastMetricRelabeling();
  public ProbeSpecFluent.MetricRelabelingsNested<A> editMatchingMetricRelabeling(Predicate<RelabelConfigBuilder> predicate);
  public String getModule();
  public A withModule(String module);
  public Boolean hasModule();
  
  /**
   * This method has been deprecated, please use method buildOauth2 instead.
   * @return The buildable object.
   */
  @Deprecated
  public OAuth2 getOauth2();
  public OAuth2 buildOauth2();
  public A withOauth2(OAuth2 oauth2);
  public Boolean hasOauth2();
  public ProbeSpecFluent.Oauth2Nested<A> withNewOauth2();
  public ProbeSpecFluent.Oauth2Nested<A> withNewOauth2Like(OAuth2 item);
  public ProbeSpecFluent.Oauth2Nested<A> editOauth2();
  public ProbeSpecFluent.Oauth2Nested<A> editOrNewOauth2();
  public ProbeSpecFluent.Oauth2Nested<A> editOrNewOauth2Like(OAuth2 item);
  
  /**
   * This method has been deprecated, please use method buildProber instead.
   * @return The buildable object.
   */
  @Deprecated
  public ProberSpec getProber();
  public ProberSpec buildProber();
  public A withProber(ProberSpec prober);
  public Boolean hasProber();
  public A withNewProber(String path,String proxyUrl,String scheme,String url);
  public ProbeSpecFluent.ProberNested<A> withNewProber();
  public ProbeSpecFluent.ProberNested<A> withNewProberLike(ProberSpec item);
  public ProbeSpecFluent.ProberNested<A> editProber();
  public ProbeSpecFluent.ProberNested<A> editOrNewProber();
  public ProbeSpecFluent.ProberNested<A> editOrNewProberLike(ProberSpec item);
  public Long getSampleLimit();
  public A withSampleLimit(Long sampleLimit);
  public Boolean hasSampleLimit();
  public String getScrapeTimeout();
  public A withScrapeTimeout(String scrapeTimeout);
  public Boolean hasScrapeTimeout();
  public Long getTargetLimit();
  public A withTargetLimit(Long targetLimit);
  public Boolean hasTargetLimit();
  
  /**
   * This method has been deprecated, please use method buildTargets instead.
   * @return The buildable object.
   */
  @Deprecated
  public ProbeTargets getTargets();
  public ProbeTargets buildTargets();
  public A withTargets(ProbeTargets targets);
  public Boolean hasTargets();
  public ProbeSpecFluent.TargetsNested<A> withNewTargets();
  public ProbeSpecFluent.TargetsNested<A> withNewTargetsLike(ProbeTargets item);
  public ProbeSpecFluent.TargetsNested<A> editTargets();
  public ProbeSpecFluent.TargetsNested<A> editOrNewTargets();
  public ProbeSpecFluent.TargetsNested<A> editOrNewTargetsLike(ProbeTargets item);
  
  /**
   * This method has been deprecated, please use method buildTlsConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public ProbeTLSConfig getTlsConfig();
  public ProbeTLSConfig buildTlsConfig();
  public A withTlsConfig(ProbeTLSConfig tlsConfig);
  public Boolean hasTlsConfig();
  public ProbeSpecFluent.TlsConfigNested<A> withNewTlsConfig();
  public ProbeSpecFluent.TlsConfigNested<A> withNewTlsConfigLike(ProbeTLSConfig item);
  public ProbeSpecFluent.TlsConfigNested<A> editTlsConfig();
  public ProbeSpecFluent.TlsConfigNested<A> editOrNewTlsConfig();
  public ProbeSpecFluent.TlsConfigNested<A> editOrNewTlsConfigLike(ProbeTLSConfig item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AuthorizationNested<N> extends Nested<N>,SafeAuthorizationFluent<ProbeSpecFluent.AuthorizationNested<N>>{
    public N and();
    public N endAuthorization();
    
  }
  public interface BasicAuthNested<N> extends Nested<N>,BasicAuthFluent<ProbeSpecFluent.BasicAuthNested<N>>{
    public N and();
    public N endBasicAuth();
    
  }
  public interface MetricRelabelingsNested<N> extends Nested<N>,RelabelConfigFluent<ProbeSpecFluent.MetricRelabelingsNested<N>>{
    public N and();
    public N endMetricRelabeling();
    
  }
  public interface Oauth2Nested<N> extends Nested<N>,OAuth2Fluent<ProbeSpecFluent.Oauth2Nested<N>>{
    public N and();
    public N endOauth2();
    
  }
  public interface ProberNested<N> extends Nested<N>,ProberSpecFluent<ProbeSpecFluent.ProberNested<N>>{
    public N and();
    public N endProber();
    
  }
  public interface TargetsNested<N> extends Nested<N>,ProbeTargetsFluent<ProbeSpecFluent.TargetsNested<N>>{
    public N and();
    public N endTargets();
    
  }
  public interface TlsConfigNested<N> extends Nested<N>,ProbeTLSConfigFluent<ProbeSpecFluent.TlsConfigNested<N>>{
    public N and();
    public N endTlsConfig();
    
  }
  
}

==> openshift-model-monitoring-6.7.2-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ProbeSpecFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ProbeSpecFluent<A extends ProbeSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAuthorization instead.
   * @return The buildable object.
   */
  @Deprecated
  public SafeAuthorization getAuthorization();
  public SafeAuthorization buildAuthorization();
  public A withAuthorization(SafeAuthorization authorization);
  public Boolean hasAuthorization();
  public ProbeSpecFluent.AuthorizationNested<A> withNewAuthorization();
  public ProbeSpecFluent.AuthorizationNested<A> withNewAuthorizationLike(SafeAuthorization item);
  public ProbeSpecFluent.AuthorizationNested<A> editAuthorization();
  public ProbeSpecFluent.AuthorizationNested<A> editOrNewAuthorization();
  public ProbeSpecFluent.AuthorizationNested<A> editOrNewAuthorizationLike(SafeAuthorization item);
  
  /**
   * This method has been deprecated, please use method buildBasicAuth instead.
   * @return The buildable object.
   */
  @Deprecated
  public BasicAuth getBasicAuth();
  public BasicAuth buildBasicAuth();
  public A withBasicAuth(BasicAuth basicAuth);
  public Boolean hasBasicAuth();
  public ProbeSpecFluent.BasicAuthNested<A> withNewBasicAuth();
  public ProbeSpecFluent.BasicAuthNested<A> withNewBasicAuthLike(BasicAuth item);
  public ProbeSpecFluent.BasicAuthNested<A> editBasicAuth();
  public ProbeSpecFluent.BasicAuthNested<A> editOrNewBasicAuth();
  public ProbeSpecFluent.BasicAuthNested<A> editOrNewBasicAuthLike(BasicAuth item);
  public SecretKeySelector getBearerTokenSecret();
  public A withBearerTokenSecret(SecretKeySelector bearerTokenSecret);
  public Boolean hasBearerTokenSecret();
  public A withNewBearerTokenSecret(String key,String name,Boolean optional);
  public String getInterval();
  public A withInterval(String interval);
  public Boolean hasInterval();
  public String getJobName();
  public A withJobName(String jobName);
  public Boolean hasJobName();
  public Long getLabelLimit();
  public A withLabelLimit(Long labelLimit);
  public Boolean hasLabelLimit();
  public Long getLabelNameLengthLimit();
  public A withLabelNameLengthLimit(Long labelNameLengthLimit);
  public Boolean hasLabelNameLengthLimit();
  public Long getLabelValueLengthLimit();
  public A withLabelValueLengthLimit(Long labelValueLengthLimit);
  public Boolean hasLabelValueLengthLimit();
  public A addToMetricRelabelings(int index,RelabelConfig item);
  public A setToMetricRelabelings(int index,RelabelConfig item);
  public A addToMetricRelabelings(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig... items);
  public A addAllToMetricRelabelings(Collection<RelabelConfig> items);
  public A removeFromMetricRelabelings(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig... items);
  public A removeAllFromMetricRelabelings(Collection<RelabelConfig> items);
  public A removeMatchingFromMetricRelabelings(Predicate<RelabelConfigBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildMetricRelabelings instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RelabelConfig> getMetricRelabelings();
  public List<RelabelConfig> buildMetricRelabelings();
  public RelabelConfig buildMetricRelabeling(int index);
  public RelabelConfig buildFirstMetricRelabeling();
  public RelabelConfig buildLastMetricRelabeling();
  public RelabelConfig buildMatchingMetricRelabeling(Predicate<RelabelConfigBuilder> predicate);
  public Boolean hasMatchingMetricRelabeling(Predicate<RelabelConfigBuilder> predicate);
  public A withMetricRelabelings(List<RelabelConfig> metricRelabelings);
  public A withMetricRelabelings(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig... metricRelabelings);
  public Boolean hasMetricRelabelings();
  public ProbeSpecFluent.MetricRelabelingsNested<A> addNewMetricRelabeling();
  public ProbeSpecFluent.MetricRelabelingsNested<A> addNewMetricRelabelingLike(RelabelConfig item);
  public ProbeSpecFluent.MetricRelabelingsNested<A> setNewMetricRelabelingLike(int index,RelabelConfig item);
  public ProbeSpecFluent.MetricRelabelingsNested<A> editMetricRelabeling(int index);
  public ProbeSpecFluent.MetricRelabelingsNested<A> editFirstMetricRelabeling();
  public ProbeSpecFluent.MetricRelabelingsNested<A> editLastMetricRelabeling();
  public ProbeSpecFluent.MetricRelabelingsNested<A> editMatchingMetricRelabeling(Predicate<RelabelConfigBuilder> predicate);
  public String getModule();
  public A withModule(String module);
  public Boolean hasModule();
  
  /**
   * This method has been deprecated, please use method buildOauth2 instead.
   * @return The buildable object.
   */
  @Deprecated
  public OAuth2 getOauth2();
  public OAuth2 buildOauth2();
  public A withOauth2(OAuth2 oauth2);
  public Boolean hasOauth2();
  public ProbeSpecFluent.Oauth2Nested<A> withNewOauth2();
  public ProbeSpecFluent.Oauth2Nested<A> withNewOauth2Like(OAuth2 item);
  public ProbeSpecFluent.Oauth2Nested<A> editOauth2();
  public ProbeSpecFluent.Oauth2Nested<A> editOrNewOauth2();
  public ProbeSpecFluent.Oauth2Nested<A> editOrNewOauth2Like(OAuth2 item);
  
  /**
   * This method has been deprecated, please use method buildProber instead.
   * @return The buildable object.
   */
  @Deprecated
  public ProberSpec getProber();
  public ProberSpec buildProber();
  public A withProber(ProberSpec prober);
  public Boolean hasProber();
  public A withNewProber(String path,String proxyUrl,String scheme,String url);
  public ProbeSpecFluent.ProberNested<A> withNewProber();
  public ProbeSpecFluent.ProberNested<A> withNewProberLike(ProberSpec item);
  public ProbeSpecFluent.ProberNested<A> editProber();
  public ProbeSpecFluent.ProberNested<A> editOrNewProber();
  public ProbeSpecFluent.ProberNested<A> editOrNewProberLike(ProberSpec item);
  public Long getSampleLimit();
  public A withSampleLimit(Long sampleLimit);
  public Boolean hasSampleLimit();
  public String getScrapeTimeout();
  public A withScrapeTimeout(String scrapeTimeout);
  public Boolean hasScrapeTimeout();
  public Long getTargetLimit();
  public A withTargetLimit(Long targetLimit);
  public Boolean hasTargetLimit();
  
  /**
   * This method has been deprecated, please use method buildTargets instead.
   * @return The buildable object.
   */
  @Deprecated
  public ProbeTargets getTargets();
  public ProbeTargets buildTargets();
  public A withTargets(ProbeTargets targets);
  public Boolean hasTargets();
  public ProbeSpecFluent.TargetsNested<A> withNewTargets();
  public ProbeSpecFluent.TargetsNested<A> withNewTargetsLike(ProbeTargets item);
  public ProbeSpecFluent.TargetsNested<A> editTargets();
  public ProbeSpecFluent.TargetsNested<A> editOrNewTargets();
  public ProbeSpecFluent.TargetsNested<A> editOrNewTargetsLike(ProbeTargets item);
  
  /**
   * This method has been deprecated, please use method buildTlsConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public ProbeTLSConfig getTlsConfig();
  public ProbeTLSConfig buildTlsConfig();
  public A withTlsConfig(ProbeTLSConfig tlsConfig);
  public Boolean hasTlsConfig();
  public ProbeSpecFluent.TlsConfigNested<A> withNewTlsConfig();
  public ProbeSpecFluent.TlsConfigNested<A> withNewTlsConfigLike(ProbeTLSConfig item);
  public ProbeSpecFluent.TlsConfigNested<A> editTlsConfig();
  public ProbeSpecFluent.TlsConfigNested<A> editOrNewTlsConfig();
  public ProbeSpecFluent.TlsConfigNested<A> editOrNewTlsConfigLike(ProbeTLSConfig item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AuthorizationNested<N> extends Nested<N>,SafeAuthorizationFluent<ProbeSpecFluent.AuthorizationNested<N>>{
    public N and();
    public N endAuthorization();
    
  }
  public interface BasicAuthNested<N> extends Nested<N>,BasicAuthFluent<ProbeSpecFluent.BasicAuthNested<N>>{
    public N and();
    public N endBasicAuth();
    
  }
  public interface MetricRelabelingsNested<N> extends Nested<N>,RelabelConfigFluent<ProbeSpecFluent.MetricRelabelingsNested<N>>{
    public N and();
    public N endMetricRelabeling();
    
  }
  public interface Oauth2Nested<N> extends Nested<N>,OAuth2Fluent<ProbeSpecFluent.Oauth2Nested<N>>{
    public N and();
    public N endOauth2();
    
  }
  public interface ProberNested<N> extends Nested<N>,ProberSpecFluent<ProbeSpecFluent.ProberNested<N>>{
    public N and();
    public N endProber();
    
  }
  public interface TargetsNested<N> extends Nested<N>,ProbeTargetsFluent<ProbeSpecFluent.TargetsNested<N>>{
    public N and();
    public N endTargets();
    
  }
  public interface TlsConfigNested<N> extends Nested<N>,ProbeTLSConfigFluent<ProbeSpecFluent.TlsConfigNested<N>>{
    public N and();
    public N endTlsConfig();
    
  }
  
}
